package cn.reghao.tnb.content.app.vod.db.mapper;

import cn.reghao.jutil.jdk.web.db.BaseMapper;
import cn.reghao.jutil.jdk.web.db.Page;
import cn.reghao.tnb.content.app.vod.model.po.PostItem;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * @author reghao
 * @date 2024-10-31 14:00:26
 */
@Mapper
public interface PostItemMapper extends BaseMapper<PostItem> {
    void deleteByAlbumIdAndPostId(@Param("albumId") long albumId, @Param("postId") String postId);

    int countByAlbumId(long albumId);
    List<PostItem> findByAlbumIdByPage(@Param("page") Page page, @Param("albumId") long albumId);
    PostItem findByImagePost(@Param("imageFileId") String imageFileId, @Param("createBy") long createBy);
    PostItem findByUrl(String url);
}
